==> haskell-project-template-0.2.0-39-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-project-template.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: project-template
version: 0.2.0
id: project-template-0.2.0-FhLOizVYXIuiuDCd5ewix
key: project-template-0.2.0-FhLOizVYXIuiuDCd5ewix
license: BSD3
maintainer: michael@fpcomplete.com
homepage: https://github.com/fpco/haskell-ide
synopsis: Specify Haskell project templates and generate files
description:
    See initial blog post for explanation: <http://www.yesodweb.com/blog/2012/09/project-templates>
category: Development
author: Michael Snoyman
exposed: True
exposed-modules:
    Text.ProjectTemplate
abi: 0c69726aabf034e08ffabc2bfa5e047c
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/project-template-0.2.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/project-template-0.2.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/project-template-0.2.0
hs-libraries: HSproject-template-0.2.0-FhLOizVYXIuiuDCd5ewix
depends:
    base-4.9.0.0 base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    bytestring-0.10.8.1 conduit-1.2.8-7nV18MBUUw27H5V6KPeFTb
    conduit-extra-1.1.15-10q3cKRpmQz8slt9iWhPKJ containers-0.5.7.1
    directory-1.2.6.2 filepath-1.4.1.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    resourcet-1.1.8.1-Fz8VsTwAt9A4JeouKpXV1P
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-project-template/html/project-template.haddock
haddock-html: /usr/share/doc/haskell-project-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-project-template-0.2.0-41-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-project-template.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: project-template
version: 0.2.0
id: project-template-0.2.0-6bKk1klf0USKEGNAbDXdyy
key: project-template-0.2.0-6bKk1klf0USKEGNAbDXdyy
license: BSD3
maintainer: michael@fpcomplete.com
homepage: https://github.com/fpco/haskell-ide
synopsis: Specify Haskell project templates and generate files
description:
    See initial blog post for explanation: <http://www.yesodweb.com/blog/2012/09/project-templates>
category: Development
author: Michael Snoyman
exposed: True
exposed-modules:
    Text.ProjectTemplate
abi: 03706922d1202ff6c2f7ee547c8a626e
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/project-template-0.2.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/project-template-0.2.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/project-template-0.2.0
hs-libraries: HSproject-template-0.2.0-6bKk1klf0USKEGNAbDXdyy
depends:
    base-4.9.0.0 base64-bytestring-1.0.0.1-In9M41tLtcS9QYt3QpGpNY
    bytestring-0.10.8.1 conduit-1.2.8-D9dRTYSavk8HJ0UStkfE43
    conduit-extra-1.1.15-FSdOtryxOIZL6vIsq9443u containers-0.5.7.1
    directory-1.2.6.2 filepath-1.4.1.0 mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    resourcet-1.1.9-J17FkGhZ2yV57Ehh8hruPC
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-project-template/html/project-template.haddock
haddock-html: /usr/share/doc/haskell-project-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
